asr.fermisurface
================

.. automodule:: asr.fermisurface

   
   
   .. rubric:: Functions

   
   .. autofunction:: add_fermi
   .. autofunction:: bz_vertices
   .. autofunction:: find_contours
   .. autofunction:: plot_fermi
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   